//+------------------------------------------------------------------+
//|                                               RSI_ATR.mq4 |
//|                      Copyright  2005, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+

extern double MagicNumber       = 546001;
extern double Lots       = 0.1;
extern double RSIPeriod = 21;
extern double ATRPeriod = 21;
extern double ATREnterPercent = 15;
extern double ATRExitPercent = 30;

bool Level1StopWatch = false;

//+------------------------------------------------------------------+
//| Calculate open positions                                         |
//+------------------------------------------------------------------+
int CalculateCurrentOrders(int type)
  {
   int orders=0;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==MagicNumber)
        {
         if(OrderType()== type)  orders++;
        }
     }
//---- return orders volume
   return(orders);
  }
  
 bool CancelPending(int type)
  {
   bool   result;
   int    cmd,total;
//----
   total=OrdersTotal();
//----
   for(int i=0; i<total; i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES))
        {
         cmd=OrderType();
         //---- pending orders only are considered
         if(cmd == type)
           {
            //---- print selected order
            OrderPrint();
            //---- delete pending order
            result=OrderDelete(OrderTicket());
            if(result!=TRUE) Print("LastError = ", GetLastError());
           }
        }
      else { Print( "Error when order select ", GetLastError()); break; }
     }
//----
   return(true);
  }
//+------------------------------------------------------------------+
//| Check for open order conditions                                  |
//+------------------------------------------------------------------+
void CheckForOpen()
  {
   double RSI, ATR;
   double OrderPrice, OrderStop;
   
//---- go trading only for first tiks of new bar
   if(Volume[0]>3) return;
   
   //periods should be days
   RSI = iRSI(NULL,PERIOD_D1,RSIPeriod, MODE_CLOSE,0);
   ATR = iATR(NULL,PERIOD_D1,ATRPeriod,0);
   
//---- sell conditions Level 1
   if(RSI < 50 && CalculateCurrentOrders(5) == 0)  
     {
      CancelPending(4);
      OrderPrice = Low[1] - ATR*(ATREnterPercent/100);
      OrderStop = OrderPrice + ATR*(ATRExitPercent/100);
      OrderSend(Symbol(),OP_SELLSTOP,Lots,OrderPrice,3,OrderStop,0,"",MagicNumber,0,Blue);
     }
//---- sell conditions Level 2
     if(RSI < 40 && CalculateCurrentOrders(1) == 0)
     {
      CancelPending(4);
      OrderSend(Symbol(),OP_SELL,Lots,Bid,3,0,0,"",MagicNumber,0,Blue);
     }
     
//---- buy conditions Level 1
   if(RSI > 50 && CalculateCurrentOrders(4) == 0)
     {
      CancelPending(5);
      OrderPrice = High[1] + ATR*(1+(ATREnterPercent/100));
      OrderStop = OrderPrice - ATR*(ATRExitPercent/100);
      OrderSend(Symbol(),OP_BUYSTOP,Lots,OrderPrice,3,OrderStop,0,"",MagicNumber,0,Blue);
     }
//---- buy conditions Level 2
     if(RSI > 60 && CalculateCurrentOrders(0) == 0)
     {
      CancelPending(5);
      OrderSend(Symbol(),OP_BUY,Lots,Ask,3,0,0,"",MagicNumber,0,Blue);
     }
//----
  }
//+------------------------------------------------------------------+
//| Check for close order conditions                                 |
//+------------------------------------------------------------------+

void CheckForModify()
  {
   double RSI, ATR;
   
   RSI = iRSI(NULL,PERIOD_D1,RSIPeriod, MODE_CLOSE,0);
   ATR = iATR(NULL,PERIOD_D1,ATRPeriod,0);
   
   for(int i=0;i<OrdersTotal();i++)
     {
     
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false)        break;
      
      if(OrderMagicNumber()!= MagicNumber || OrderSymbol()!=Symbol()) {
      //---- check order type 
      
      if(OrderType()==OP_BUYSTOP)
        { 
            if(RSI < 70 && Level1StopWatch == true)
            {
            OrderClose(OrderTicket(),OrderLots(),Bid,3,Violet);
            Level1StopWatch = false;
            }
        
            if(RSI > 70 && Level1StopWatch == false)
            {
            Level1StopWatch = true;
            }
            
        }
        
      if(OrderType()==OP_SELLSTOP)
        { 
            if(RSI > 30 && Level1StopWatch == true)
            {
            OrderClose(OrderTicket(),OrderLots(),Ask,3,Violet);
            Level1StopWatch = false;
            }
        
            if(RSI < 30 && Level1StopWatch == false)
            {
            Level1StopWatch = true;
            }
            
        }
       if(OrderType()==OP_BUY)
        { 
            if(RSI < 40 || CalculateCurrentOrders(1) != 0)
            {
            OrderClose(OrderTicket(),OrderLots(),Bid,3,Violet);
            }
            
        }
      if(OrderType()==OP_SELL)
        { 
            if(RSI > 60 || CalculateCurrentOrders(0) != 0)
            {
            OrderClose(OrderTicket(),OrderLots(),Bid,3,Violet);
            }
        
        }
        
        
        
      }
        
            
        
     }
//----
  }
//+------------------------------------------------------------------+
//| Start function                                                   |
//+------------------------------------------------------------------+
void start()
  {
//---- check for history and trading
   if(Bars<100 || IsTradeAllowed()==false) return;
//---- calculate open orders by current symbol
   CheckForOpen();
   CheckForModify();
//----
  }
//+------------------------------------------------------------------+